import { EncryptUtil } from '@backset/util';
import { Injectable } from '@nestjs/common';
import { InjectDataSource } from '@nestjs/typeorm';
import { IUserLoginRequest } from 'src/dto/user.dto';
import { IUser } from 'src/entity/user.entity';
import { DataSource } from 'typeorm';
import { AuthServiceImpl } from './impl/auth.interface';
import jwt = require('jsonwebtoken');
import { TOKEN } from 'src/config/constant';

@Injectable()
export class AuthService implements AuthServiceImpl {
  constructor(@InjectDataSource() private db: DataSource) {}

  /**
   * 生成用户 token 存 redis 的 key
   */
  getRedisKey(user: IUser): string {
    return `${user.id}-${user.user_login}`;
  }

  async userLogin(p: IUserLoginRequest): Promise<IUser> {
    try {
      const select_sql = `SELECT 
        id,
        user_login
        user_phone,
        display_name,
        user_email,
        user_create_time,
        user_status 
      FROM user WHERE user_login = ? and user_pass = ?`;
      const user = await this.db.query(select_sql, [
        p.user_login,
        EncryptUtil.md5(p.user_pass),
      ]);
      return user.length > 0 ? user[0] : null;
    } catch (error) {
      throw new Error(error);
    }
  }
}
